// This file is generated by kconfig_compiler_kf6 from grantleethemeeditor.kcfg.
// All changes you do to this file will be lost.
#ifndef GRANTLEETHEMEEDITOR_GRANTLEETHEMEEDITORSETTINGS_H
#define GRANTLEETHEMEEDITOR_GRANTLEETHEMEEDITORSETTINGS_H

#include <grantleethemeeditor_export.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace GrantleeThemeEditor {

class GRANTLEETHEMEEDITOR_EXPORT GrantleeThemeEditorSettings : public KConfigSkeleton
{
  public:

    static GrantleeThemeEditorSettings *self();
    ~GrantleeThemeEditorSettings() override;

    /**
      Set Store author email
    */
    static
    void setAuthorEmail( const QString & v )
    {
      if (!self()->isAuthorEmailImmutable())
        self()->mAuthorEmail = v;
    }

    /**
      Get Store author email
    */
    static
    QString authorEmail()
    {
      return self()->mAuthorEmail;
    }

    /**
      Is Store author email Immutable
    */
    static
    bool isAuthorEmailImmutable()
    {
      return self()->isImmutable( QStringLiteral( "authorEmail" ) );
    }

    /**
      Get Item object corresponding to authorEmail()
    */
    ItemString *authorEmailItem()
    {
      return mAuthorEmailItem;
    }

    /**
      Set Store author name
    */
    static
    void setAuthor( const QString & v )
    {
      if (!self()->isAuthorImmutable())
        self()->mAuthor = v;
    }

    /**
      Get Store author name
    */
    static
    QString author()
    {
      return self()->mAuthor;
    }

    /**
      Is Store author name Immutable
    */
    static
    bool isAuthorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "author" ) );
    }

    /**
      Get Item object corresponding to author()
    */
    ItemString *authorItem()
    {
      return mAuthorItem;
    }

    /**
      Set Default theme path
    */
    static
    void setPath( const QString & v )
    {
      if (!self()->isPathImmutable())
        self()->mPath = v;
    }

    /**
      Get Default theme path
    */
    static
    QString path()
    {
      return self()->mPath;
    }

    /**
      Is Default theme path Immutable
    */
    static
    bool isPathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "path" ) );
    }

    /**
      Get Item object corresponding to path()
    */
    ItemString *pathItem()
    {
      return mPathItem;
    }

  protected:
    GrantleeThemeEditorSettings();
    friend class GrantleeThemeEditorSettingsHelper;


    // Global
    QString mAuthorEmail;
    QString mAuthor;
    QString mPath;

  private:
    ItemString *mAuthorEmailItem;
    ItemString *mAuthorItem;
    ItemString *mPathItem;
};

}

#endif

